Update of /cvsroot/monetdb/pathfinder/compiler/debug
In directory sc8-pr-cvs16.sourceforge.net:/tmp/cvs-serv1296/compiler/debug

Modified Files:
      Tag: xquery-decomposition
        logdebug.c physdebug.c 
Log Message:
propagated changes up to Thursday Jan 17 2008
from the development trunk to the xquery-decomposition branch


Index: logdebug.c
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/debug/logdebug.c,v
retrieving revision 1.86
retrieving revision 1.86.2.1
diff -u -d -r1.86 -r1.86.2.1
--- logdebug.c  11 Jan 2008 12:49:09 -0000      1.86
+++ logdebug.c  17 Jan 2008 08:36:38 -0000      1.86.2.1
@@ -1041,13 +1041,25 @@
                     }
                 }
                 fst = true;
                 /* list distribution columns */
                 for (unsigned int i = 0; i < n->schema.count; i++) {
                     PFalg_att_t att = n->schema.items[i].name;
-                    if (PFprop_req_distr_col (n->prop, att)) {
+                    if (PFprop_req_order_col (n->prop, att)) {
                         PFarray_printf (
                             dot, 
-                            fst ? "\\ndistr col: %s" : ", %s",
+                            fst ? "\\norder col: %s" : ", %s",
+                            PFatt_str (att));
+                        fst = false;
+                    }
+                }
+                fst = true;
+                /* list bijective columns */
+                for (unsigned int i = 0; i < n->schema.count; i++) {
+                    PFalg_att_t att = n->schema.items[i].name;
+                    if (PFprop_req_bijective_col (n->prop, att)) {
+                        PFarray_printf (
+                            dot, 
+                            fst ? "\\nbijective col: %s" : ", %s",
                             PFatt_str (att));
                         fst = false;
                     }
@@ -1527,11 +1539,55 @@
 
         case la_empty_tbl:
             PFarray_printf (xml, "    <content>\n"); 
+
             /* list the attributes of this table */
-            for (c = 0; c < n->schema.count;c++)
-                PFarray_printf (xml, 
-                                "      <column name=\"%s\" new=\"true\"/>\n",
-                                PFatt_str (n->schema.items[c].name));
+            for (unsigned int i = 0; i < n->schema.count; i++) {
+                bool first = true;
+
+                PFarray_printf (xml, "      <column name=\"%s\" type=\"",
+                                PFatt_str (n->schema.items[i].name));
+
+                if (n->schema.items[i].type & aat_update)
+                    PFarray_printf (xml, "update");
+                else
+                    for (PFalg_simple_type_t t = 1; t; t <<= 1) {
+                        if (t & n->schema.items[i].type) {
+                            /* hide fragment information */
+                            switch (t) {
+                                case aat_afrag:
+                                case aat_pfrag:
+                                    continue;
+                                default:
+                                    break;
+                            }
+
+                            /* start printing spaces only after the first type 
*/
+                            if (!first)
+                                PFarray_printf (xml, " ");
+                            else
+                                first = false;
+
+                            /* print the different types */
+                            switch (t) {
+                                case aat_nat:    PFarray_printf (xml, "nat");  
 break;
+                                case aat_int:    PFarray_printf (xml, "int");  
 break;
+                                case aat_str:    PFarray_printf (xml, "str");  
 break;
+                                case aat_dec:    PFarray_printf (xml, "dec");  
 break;
+                                case aat_dbl:    PFarray_printf (xml, "dbl");  
 break;
+                                case aat_bln:    PFarray_printf (xml, "bln");  
 break;
+                                case aat_qname:  PFarray_printf (xml, 
"qname"); break;
+                                case aat_uA:     PFarray_printf (xml, "uA");   
 break;
+                                case aat_attr:   PFarray_printf (xml, "attr"); 
 break;
+                                case aat_pre:    PFarray_printf (xml, "node"); 
 break;
+                                default:                                       
 break;
+                            }
+                        }
+                    }
+                PFarray_printf (xml, "\" new=\"true\"/>\n");
+            }
+
+             
+
 
             PFarray_printf (xml, "    </content>\n");
             break;
@@ -1041,13 +1041,25 @@
                 }
                 fst = true;
-                /* list distribution columns */
+                /* list order columns */
                 for (unsigned int i = 0; i < n->schema.count; i++) {
                     PFalg_att_t att = n->schema.items[i].name;

Index: physdebug.c
===================================================================
RCS file: /cvsroot/monetdb/pathfinder/compiler/debug/physdebug.c,v
retrieving revision 1.49
retrieving revision 1.49.2.1
diff -u -d -r1.49 -r1.49.2.1
--- physdebug.c 11 Jan 2008 12:49:09 -0000      1.49
+++ physdebug.c 17 Jan 2008 08:36:39 -0000      1.49.2.1
@@ -874,13 +874,25 @@
                     }
                 }
                 fst = true;
                 /* list distribution columns */
                 for (unsigned int i = 0; i < n->schema.count; i++) {
                     PFalg_att_t att = n->schema.items[i].name;
-                    if (PFprop_req_distr_col (n->prop, att)) {
+                    if (PFprop_req_order_col (n->prop, att)) {
                         PFarray_printf (
                             dot, 
-                            fst ? "\\ndistr col: %s" : ", %s",
+                            fst ? "\\norder col: %s" : ", %s",
+                            PFatt_str (att));
+                        fst = false;
+                    }
+                }
+                fst = true;
+                /* list bijective columns */
+                for (unsigned int i = 0; i < n->schema.count; i++) {
+                    PFalg_att_t att = n->schema.items[i].name;
+                    if (PFprop_req_bijective_col (n->prop, att)) {
+                        PFarray_printf (
+                            dot, 
+                            fst ? "\\nbijective col: %s" : ", %s",
                             PFatt_str (att));
                         fst = false;
                     }


-------------------------------------------------------------------------
@@ -874,13 +874,25 @@
                 }
                 fst = true;
-                /* list distribution columns */
+                /* list order columns */
                 for (unsigned int i = 0; i < n->schema.count; i++) {
                     PFalg_att_t att = n->schema.items[i].name;
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2008.
http://clk.atdmt.com/MRT/go/vse0120000070mrt/direct/01/
_______________________________________________
Monetdb-pf-checkins mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/monetdb-pf-checkins

Reply via email to